==> nextcloud-12.0.7.tar.bz2: nextcloud/apps/comments/l10n/et_EE.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentaarid",
    "Edit comment" : "Muuda kommentaari",
    "Delete comment" : "Kustuta kommentaar",
    "New comment …" : "Uus kommentaar",
    "Post" : "Postita",
    "Cancel" : "Loobu",
    "[Deleted user]" : "[Kustutatud kasutaja]",
    "No comments yet, start the conversation!" : "Kommentaare veel pole, alusta vestlust",
    "More comments …" : "Veel kommentaare ...",
    "Save" : "Salvesta",
    "Allowed characters {count} of {max}" : "Lubatud märkide arv {count}/{max}",
    "Error occurred while updating comment with id {id}" : "Kommentaari {id} uuendamisel tekkis tõrge",
    "Error occurred while posting comment" : "Viga kommentaari postitamisel",
    "_%n unread comment_::_%n unread comments_" : ["%n lugemata kommentaar","%n lugemata kommentaari"],
    "Comment" : "Kommentaar",
    "You commented" : "Sa kommenteerisid",
    "%1$s commented" : "%1$s kommenteeris",
    "{author} commented" : "{author} kommenteeris",
    "You commented on %1$s" : "Sa kommmenteerisid %1$s",
    "You commented on {file}" : "Sa kommenteerisid faili {file}",
    "%1$s commented on %2$s" : "%1$s kommenteeris %2$s",
    "{author} commented on {file}" : "{author} kommenteeris faili {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentaarid</strong> failidele",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Sind mainiti \"%s\", kommentaaris kasutataja poolt, mis on praeguseks kustutatud",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sind mainiti \"{file}\", kommentaaris kasutataja poolt, mis on praeguseks kustutatud",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mainis sind \"%2$s\" kommentaaris",
    "{user} mentioned you in a comment on “{file}”" : "{user} mainis sind faili “{file}” kommentaaris",
    "Unknown user" : "Tundmatu kasutaja",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Kustutatud kasutaja mainis sind \"%s\" kommentaaris",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Kustutatud kasutaja mainis sind faili \"{file}\" kommentaaris"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.4.tar.bz2: nextcloud/apps/comments/l10n/et_EE.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Muuda kommentaari",
    "Delete comment" : "Kustuta kommentaar",
    "New comment …" : "Uus kommentaar",
    "Post" : "Postita",
    "Cancel" : "Loobu",
    "[Deleted user]" : "[Kustutatud kasutaja]",
    "Comments" : "Kommentaarid",
    "No comments yet, start the conversation!" : "Kommentaare veel pole, alusta vestlust",
    "More comments …" : "Veel kommentaare ...",
    "Save" : "Salvesta",
    "Allowed characters {count} of {max}" : "Lubatud märkide arv {count}/{max}",
    "Error occurred while updating comment with id {id}" : "Kommentaari {id} uuendamisel tekkis tõrge",
    "Error occurred while posting comment" : "Viga kommentaari postitamisel",
    "_%n unread comment_::_%n unread comments_" : ["%n lugemata kommentaar","%n lugemata kommentaari"],
    "Comment" : "Kommentaar",
    "You commented" : "Sa kommenteerisid",
    "%1$s commented" : "%1$s kommenteeris",
    "{author} commented" : "{author} kommenteeris",
    "You commented on %1$s" : "Sa kommmenteerisid %1$s",
    "You commented on {file}" : "Sa kommenteerisid faili {file}",
    "%1$s commented on %2$s" : "%1$s kommenteeris %2$s",
    "{author} commented on {file}" : "{author} kommenteeris faili {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentaarid</strong> failidele",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sind mainiti \"{file}\", kommentaaris kasutataja poolt, mis on praeguseks kustutatud",
    "{user} mentioned you in a comment on “{file}”" : "{user} mainis sind faili “{file}” kommentaaris",
    "Unknown user" : "Tundmatu kasutaja",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Kustutatud kasutaja mainis sind \"%s\" kommentaaris",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Kustutatud kasutaja mainis sind faili \"{file}\" kommentaaris",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mainis sind \"%2$s\" kommentaaris",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Sind mainiti \"%s\", kommentaaris kasutataja poolt, mis on praeguseks kustutatud"
},
"nplurals=2; plural=(n != 1);");
